function ret_val = createKeaCameraGige(processing_config, serial, varargin)
  % createKeaCameraGige
  %   Construct a kea camera using the gige interface. This could be useful in
  %   two cases. The first is when the camera is connected with both usb and
  %   ethernet but you want to use ethernet. The second is when for some reason
  %   the default maximum packet size is too large.
  %
  % Inputs:
  %   processing_config - ProcessingConfig - The processing config
  %   serial - string - The serial number of the camera to connect to, if the
  %                     camera is available over both usb and gige it will be
  %                     connected over usb. If an empty string is supplied the
  %                     camera will connect to the first usb camera, if no usb
  %                     camera is connected it will connect to the first gige
  %                     camera that replies (this reply time is random, so you
  %                     might connect to a different camera each time if you've
  %                     got multiple cameras connected to your network). If no
  %                     camera is found with the given serial number a nullptr
  %                     and error is returned.
  %   packet_size = 1472 - numeric - The packet size to use for communication
  %                                  over ethernet
  %
  % Output:
  %   ret_val - KeaCamera - A kea camera
  %

  packet_size = 1472;
  if size(varargin, 2) == 1
    packet_size = varargin{1};
  end

  ret_val = tof.mex('tof_create_kea_camera_gige', processing_config.get_object_ptr(), serial, packet_size);
  ret_val = tof.KeaCamera(ret_val);
end

