#include <chronoptics/tof.hpp>
#include <iostream>

namespace tof = chronoptics::tof;

template <typename Array>
void print_array(const char* name, const Array& array) {
  std::cout << name << ": ";
  for (auto val : array) {
    std::cout << val << " ";
  }
  std::cout << "\n";
}

int main() {
  tof::KeaCamera cam("202001a");

  auto cal = cam.get_calibration();

  auto lens_matrix = cal.get_depth_camera_matrix();
  print_array("Lens matrix", lens_matrix);

  auto distortion_coeff = cal.get_depth_distortion_coefficients();
  print_array("Distortion coefficients", distortion_coeff);

  auto camera_config = cam.get_camera_config();
  camera_config.reset();

  camera_config.set_modulation_frequency(0, 80.0f);
  camera_config.set_phase_shifts(0, {0.f, 0.25f, 0.375f, 0.625f});
  camera_config.set_integration_time(0, {300, 300, 300, 300});
  camera_config.set_duty_cycle(0, 0.35f);

  camera_config.add_frame();
  camera_config.set_modulation_frequency(1, 100.0f);
  camera_config.set_phase_shifts(1, {0.f, 0.25f, 0.375f, 0.625f});
  camera_config.set_integration_time(1, {300, 300, 300, 300});
  camera_config.set_duty_cycle(1, 0.35f);

  tof::ProcessingConfig proc_config{};
  proc_config.set_temporal_enabled(true);
  proc_config.set_median_enabled(true);
  proc_config.set_phase_unwrapping_enabled(true);
  proc_config.set_flying_enabled(true);

  cam.set_configurations(camera_config, proc_config);

  tof::select_streams(cam, {tof::FrameType::RADIAL, tof::FrameType::INTENSITY});

  cam.start();
  auto frames = cam.get_frames();
  (void)frames;
}